%capacitor
% Plots the electric field strength (and direction) of a parallel plate
% capacitor.
%
% LAST UPDATED by Andy French September 2016

function capacitor

%Electron charge /coulombs
qe = 1.602e-19;

%Number of line charges per plate
numQ = 20;

%Set charges
q = qe*[-ones(1,numQ),ones(1,numQ)];

%Plate separation /m
a = 0.05;

%Plate length /m
L = 0.1;

%Set charge coordinates
xq = [ linspace( -L/2, L/2, numQ) , linspace( -L/2, L/2, numQ) ];
yq = a/2*[-ones(1,numQ),ones(1,numQ)];

%Set plot options
xlimits = L*[-1,1];
ylimits = L*[-1,1];
plot_title = 'Capacitor';
options.interp_background = 1;
options.field_lines = 1;
options.overlay_contour_lines = 0;
options.plot_charges = 1;

%Visualize electric field
[Ex,Ey,V,x,y] = efield( xq, yq,zeros(size(xq)), q, xlimits, ylimits, plot_title, options );

%End of code