%dodecahedron
% Plots the electric field strength (and direction) of point charges arranged
% at the vertices of a dodecahedron. This is the solid with the most points
% that are equally distributed on the surface of a sphere.
%
% LAST UPDATED by Andy French September 2016

function dodecahedron

%Number of charges to be placed around (half) a great circle of the sphere
numQ = 40;

%Sphere radius /m
a = 0.1;

%Electron charge /coulombs
qe = 1.602e-19;

%Set plot options
xlimits = 2*a*[-1,1];
ylimits = 2*a*[-1,1];
plot_title = 'Dodecahedron from point charges';
options.interp_background = 1;
options.field_lines = 0;
options.overlay_contour_lines = 0;
options.plot_charges = 1;

%Determine charge (x,y,z) coordinates
p=(1+sqrt(5))/2; q=1/p;
xyz=[ 1, 1 ,1;  1,-1,-1;  1, 1,-1;  1,-1, 1;...
    -1, 1, 1; -1,-1,-1; -1, 1,-1; -1,-1, 1;...
    0, q, p;  0, q,-p;  0,-q, p;  0,-q,-p;...
    q, p, 0;  q,-p, 0; -q ,p, 0; -q,-p, 0;...
    p, 0, q;  p, 0,-q; -p, 0, q; -p, 0,-q
    ];
xq = xyz(:,1).';
yq = xyz(:,2).';
zq = xyz(:,3).';

% figure;
% plot3(xq,yq,zq,'r*');
% axis vis3d

%Set charges
q = qe*ones(1,20);

%Visualize electric field
[Ex,Ey,V,x,y] = efield( xq, yq, zq, q, xlimits, ylimits, plot_title, options );

%End of code