%dipole
% Plots the electric field strength (and direction) of a static N-pole.
%
% LAST UPDATED by Andy French September 2016

function npole

%Number of charges
numQ = 20;

%Average charge separation /m
a = 1e-2;

%Electron charge /coulombs
qe = 1.602e-19;

%Maximum charge /coulombs
Q = 2*qe;

%Set plot options
xlimits = 2*a*[-1,1];
ylimits = 2*a*[-1,1];
plot_title = [num2str(numQ),' random point charges'];
options.interp_background = 1;
options.field_lines = 1;
options.overlay_contour_lines = 0;
options.plot_charges = 1;

%Randomly determine charge (x,y) coordinates and charges
for k=1:numQ
    xq(k) = xlimits(1) + ( xlimits(2) - xlimits(1) )*rand;
    yq(k) = ylimits(1) + ( ylimits(2) - ylimits(1) )*rand;
    q(k) = -Q + 2*Q*rand; 
end

%Visualize electric field
[Ex,Ey,V,x,y] = efield( xq, yq,zeros(size(xq)), q, xlimits, ylimits, plot_title, options );

%End of code