%ring_from_point_charges
% Plots the electric field strength (and direction) of point charges formed
% into a circle.
%
% LAST UPDATED by Andy French September 2016

function ring_from_point_charges

%Number of charges to be placed around sphere
numQ = 20;

%Inner ring radius /m
a = 1e-3;

%Outer ring radius /m
b = 5*a;

%Electron charge /coulombs
qe = 1.602e-19;

%Set charges
q = [ qe*ones(1,numQ),-qe*ones(1,numQ) ];
q = qe*ones(1,numQ);

%Set plot options
xlimits = 2*b*[-1,1];
ylimits = 2*b*[-1,1];
plot_title = 'Ring from point charges';
options.interp_background = 1;
options.field_lines = 1;
options.overlay_contour_lines = 0;
options.plot_charges = 1;

%Determine charge (x,y) coordinates
theta = linspace( 0, 2*pi - 2*pi/numQ, numQ );
xq_in = a*cos(theta);
yq_in = a*sin(theta);
xq_out = b*cos(theta);
yq_out = b*sin(theta);
xq = [xq_in,xq_out];
yq = [yq_in,yq_out];
xq = xq_out;
yq = yq_out;

%Visualize electric field
[Ex,Ey,V,x,y] = efield( xq, yq, zeros(size(xq)), q, xlimits, ylimits, plot_title, options );

%End of code