%sphere_from_point_charges
% Plots the electric field strength (and direction) of point charges formed
% into the surface of a sphere.
%
% LAST UPDATED by Andy French September 2016

function sphere_from_point_charges

%Number of charges to be placed around (half) a great circle of the sphere
numQ = 60;

%Sphere radius /m
a = 0.1;

%Electron charge /coulombs
qe = 1.602e-19;

%Set plot options
xlimits = 2*a*[-1,1];
ylimits = 2*a*[-1,1];
plot_title = 'Sphere from point charges';
options.interp_background = 1;
options.field_lines = 1;
options.overlay_contour_lines = 0;
options.plot_charges = 0;

%Determine charge (x,y,z) coordinates

%Latitude and longitude rings (note this won't be an even charge
%distribution!)
phi = linspace( 0, 2*pi - 2*pi/(2*numQ), 2*numQ );
theta = linspace( 0, pi - pi/numQ, numQ );

% %Randomly chosen lat, long angles
% phi = 2*pi*rand(1,2*numQ);
% theta = pi*rand(1,numQ);

%Determine charge coordinates
[phi,theta] = meshgrid(phi,theta);
xq = a*cos(phi).*sin(theta);
yq = a*sin(phi).*sin(theta);
zq = a*cos(theta);
xq = reshape(xq,[1,numel(xq)]);
yq = reshape(yq,[1,numel(yq)]);
zq = reshape(zq,[1,numel(zq)]);

% figure;
% plot3(xq,yq,zq,'r*');
% axis vis3d

%Set charges
q = qe*ones(1,2*numQ^2);

%Visualize electric field
[Ex,Ey,V,x,y] = efield( xq, yq, zq, q, xlimits, ylimits, plot_title, options );

%End of code